Inventory

Notedocblock

resolve_inventory An in-memory representation of a Sphinx objects.inv inventory.

Fields

  • project::String: Project name from the inventory header.
  • version::String: Project version from the inventory header.
  • items::Vector{InventoryItem}: All inventory entries.
  • root_url::String: Base URL the URIs are relative to (empty for inventories that were not loaded from a URL). Used by resolve_inventory to build absolute links.
  • lookup::Dict{String,Int}: Name => index map for O(1) resolution.

Notedocblock

Inventory Construct an Inventory from project, version and a vector of InventoryItems, building the name lookup table automatically. root_url is the base URL the item URIs are relative to.