load_inventory

Notedocblock

resolve_inventory Load a Sphinx objects.inv inventory from source.

If source starts with http:// or https:// it is downloaded to a temporary file (using the Downloads stdlib) and root_url defaults to the directory containing the inventory (the part of the URL before the trailing /objects.inv). Otherwise source is treated as a local file path and root_url defaults to "" (override it to make resolve_inventory produce absolute URLs).

The four-line header is parsed for project/version, then the zlib-compressed body is inflated and parsed into InventoryItems.