quarto_doc_page
Notedocblock
quarto_doc_page(s; dir = "docs/reference", name = nothing)Given a symbol or binding s, write its .qmd doc into the folder dir.
When name is given, it is used for both the output file name (<dir>/<name>.qmd) and the page H1 title; otherwise the name is derived from s via _doc_page_name, preserving the default behaviour.